src.service package
===================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   src.service.clientsvc
   src.service.serversvc

Module contents
---------------

.. automodule:: src.service
   :members:
   :show-inheritance:
   :undoc-members:
